@@ -125,20 +125,30 @@ remove_notify_id (gpointer data)
 }
 
 void
-gconf_bookmarks_hook_up_menu (GConfEditorWindow *window, GtkWidget *menu)
+gconf_bookmarks_hook_up_menu (GConfEditorWindow *window,
+			      GtkWidget *menu,
+			      GtkWidget *add_bookmark,
+			      GtkWidget *edit_bookmarks)
 {
+	GConfClient *client;
 	guint notify_id;
 
 	g_object_set_data (G_OBJECT (menu), "editor-window", window);
+
+	client = gconf_client_get_default ();
 	
 	/* Add a notify function */
-	gconf_client_add_dir (gconf_client_get_default (), "/apps/gconf-editor/bookmarks",
+	gconf_client_add_dir (client, "/apps/gconf-editor/bookmarks",
 			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	notify_id = gconf_client_notify_add (gconf_client_get_default (), "/apps/gconf-editor/bookmarks",
+	notify_id = gconf_client_notify_add (client, "/apps/gconf-editor/bookmarks",
 					     gconf_bookmarks_key_changed, menu, NULL, NULL);
 	g_object_set_data_full (G_OBJECT (menu), "notify-id", GINT_TO_POINTER (notify_id),
 				remove_notify_id);
 
 	gconf_bookmarks_update_menu (menu);
 
+	if ( ! gconf_client_key_is_writable (client, "/apps/gconf-editor/bookmarks", NULL)) {
+		gtk_widget_set_sensitive (add_bookmark, FALSE);
+		gtk_widget_set_sensitive (edit_bookmarks, FALSE);
+	}
 }
